This function to remove redundant geneIDs standing for the same gene name
collapse_deg(diffexp, genenamecol, pcriteria)
Arguments
- diffexp
data.frame/data.table output of the deg.def() function
- genenamecol
the column name of the gene name variable <string>
- pcriteria
the column name of the pvalue criteria to consider <string>
Value
data.table differential expression results with unique gene
names
Examples
data(diffexplist)
diffexp <- collapse_deg(diffexplist[[1]], "Symbol", "pvalue")
head(diffexp, 3)
#> Symbol Log2FC pvalue CI.L CI.R
#> 1 ANG -2.457422 4.989567e-15 -2.681351 -2.233493
#> 2 ANKK1 3.170765 2.434825e-13 2.810801 3.530728
#> 3 JCHAIN -5.037828 5.818145e-13 -5.638979 -4.436677